defmodule PrometheusTelemetry.MetricsExporterPlug do
  @moduledoc """
  This is the exporter for prometheus that sets up metrics to be scraped

  It uses /metrics as a route and is setup on port 4050 by default
  """

  use Supervisor

  def start_link(opts \\ []) do
    name = server_name(opts[:port])

    case Process.whereis(name) do
      nil -> Supervisor.start_link(PrometheusTelemetry.MetricsExporterPlug, opts, name: name)
      _pid -> :ignore
    end
  end

  defp server_name(port) do
    :"prometheus_telemetry_metrics_exporter_plug_#{port}"
  end

  def init(opts) do
    Supervisor.init([
      Plug.Cowboy.child_spec(
        scheme: opts[:protocol],
        plug: PrometheusTelemetry.Router,
        options: [port: opts[:port]]
      )
    ], strategy: :one_for_one)
  end
end
